==> config_auto_export-2.1.4.tar.gz: config_auto_export/src/Form/Settings.php <==
<?php

namespace Drupal\config_auto_export\Form;

use Drupal\config_auto_export\FileStorageFactory;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure 'config auto export' settings for this site.
 */
class Settings extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames(): array {
    return [
      'config_auto_export.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'config_auto_export_settings';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $config = $this->config('config_auto_export.settings');
    $form['enabled'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enabled'),
      '#default_value' => $config->get('enabled'),
    ];
    $form['directory'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Directory'),
      '#default_value' => $config->get('directory'),
    ];
    $form['webhook'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Webhook'),
      '#default_value' => $config->get('webhook'),
      '#maxlength' => 1024,
    ];
    $form['webhook_params'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Params'),
      '#default_value' => $config->get('webhook_params'),
      '#attributes' => ['data-yaml-editor' => 'true'],
    ];
    $form['delay'] = [
      '#type' => 'number',
      '#title' => $this->t('Delay in seconds'),
      '#default_value' => $config->get('delay'),
      '#description' => $this->t('Set this to zero to export config changes without any delay. If you provide a value higher than that, the export will be triggered by the next feasible cron after that period.'),
      '#min' => 0,
    ];
    $form['delay_from_first'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Calculate delay from first event'),
      '#default_value' => $config->get('delay_from_first'),
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    parent::submitForm($form, $form_state);

    if ($form_state->getValue('directory') !== FileStorageFactory::getDirectory()) {
      FileStorageFactory::removeSync();
    }
    $this->config('config_auto_export.settings')
      ->set('enabled', $form_state->getValue('enabled'))
      ->set('directory', $form_state->getValue('directory'))
      ->set('webhook', $form_state->getValue('webhook'))
      ->set('webhook_params', $form_state->getValue('webhook_params'))
      ->set('delay', $form_state->getValue('delay'))
      ->set('delay_from_first', $form_state->getValue('delay_from_first'))
      ->save();
  }

}

==> config_auto_export-2.2.1.tar.gz: config_auto_export/src/Form/Settings.php <==
<?php

namespace Drupal\config_auto_export\Form;

use Drupal\config_auto_export\FileStorageFactory;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure 'config auto export' settings for this site.
 */
class Settings extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames(): array {
    return [
      'config_auto_export.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'config_auto_export_settings';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $config = $this->config('config_auto_export.settings');
    $form['enabled'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enabled'),
      '#default_value' => $config->get('enabled'),
    ];
    $form['directory'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Directory'),
      '#default_value' => $config->get('directory'),
    ];
    $form['webhook'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Webhook'),
      '#default_value' => $config->get('webhook'),
      '#maxlength' => 1024,
    ];
    $form['webhook_params'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Params'),
      '#default_value' => $config->get('webhook_params') ?? '',
      '#attributes' => ['data-yaml-editor' => 'true'],
    ];
    $form['webhook_headers'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Headers'),
      '#default_value' => $config->get('webhook_headers') ?? '',
      '#attributes' => ['data-yaml-editor' => 'true'],
    ];
    $form['webhook_autorun_enabled'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Automatically run webhook'),
      '#default_value' => $config->get('webhook_autorun_enabled'),
    ];
    $form['delay'] = [
      '#type' => 'number',
      '#title' => $this->t('Delay in seconds'),
      '#default_value' => $config->get('delay'),
      '#description' => $this->t('Set this to zero to export config changes without any delay. If you provide a value higher than that, the export will be triggered by the next feasible cron after that period.'),
      '#min' => 0,
      '#states' => [
        'visible' => [
          ':input[name="webhook_autorun_enabled"]' => ['checked' => TRUE],
        ],
      ],
    ];
    $form['delay_from_first'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Calculate delay from first event'),
      '#default_value' => $config->get('delay_from_first'),
      '#states' => [
        'visible' => [
          ':input[name="webhook_autorun_enabled"]' => ['checked' => TRUE],
        ],
      ],
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    parent::submitForm($form, $form_state);

    if ($form_state->getValue('directory') !== FileStorageFactory::getDirectory()) {
      FileStorageFactory::removeSync();
    }
    $this->config('config_auto_export.settings')
      ->set('enabled', $form_state->getValue('enabled'))
      ->set('directory', $form_state->getValue('directory'))
      ->set('webhook', $form_state->getValue('webhook'))
      ->set('webhook_params', $form_state->getValue('webhook_params'))
      ->set('webhook_headers', $form_state->getValue('webhook_headers'))
      ->set('webhook_autorun_enabled', $form_state->getValue('webhook_autorun_enabled'))
      ->set('delay', $form_state->getValue('delay'))
      ->set('delay_from_first', $form_state->getValue('delay_from_first'))
      ->save();
  }

}
